SET search_path = public;

BEGIN;

-- In the case that you already have a configuration set for the locale, and you are changing it to your new dictionary configuration. You will have to set the old locale to NULL. If we are using the 'C' locale then we would do this:

-- Nota: Yo creo q aca seria es_NI en lugar de C, pero no estoy seguro
-- UPDATE pg_ts_cfg SET locale=NULL WHERE locale = 'C';

UPDATE pg_ts_cfg SET locale=NULL WHERE locale = 'es_NI';


-- We will create a new configuration for use with the server encoding 'es_NI'.

INSERT INTO pg_ts_cfg (ts_name, prs_name, locale)
               VALUES ('default_spanish', 'default', 'es_NI');

-- You can now add the tsearch2 configuration entry for the ISpell spanish dictionary.

INSERT INTO pg_ts_dict
               (SELECT 'es_ispell',
                       dict_init,
                       'DictFile="/usr/local/pgsql/share/contrib/espanol.dict",'
                       'AffFile="/usr/local/pgsql/share/contrib/espanol.aff",'
                       'StopFile="/usr/local/pgsql/share/contrib/espanol.stop"',
                       dict_lexize
                FROM pg_ts_dict
                WHERE dict_name = 'ispell_template');

-- If you wanted to always use the ISpell english dictionary you have installed, you can configure tsearch2 to always use a specific dictionary.

-- SELECT set_curdict('es_ispell');

-- Next we need to set up the configuration for mapping the dictionay use to the lexxem parsings. This will be done by altering the pg_ts_cfgmap table. We will insert several rows, specifying to use the new dictionary we installed and configured for lexizing within tsearch2. There are several type of lexims we would be concerned with forcing the use of the ISpell dictionary.

INSERT INTO pg_ts_cfgmap (ts_name, tok_alias, dict_name)
	VALUES ('default_spanish', 'lhword', '{es_ispell,en_stem}');
INSERT INTO pg_ts_cfgmap (ts_name, tok_alias, dict_name)
        VALUES ('default_spanish', 'lpart_hword', '{es_ispell,en_stem}');
INSERT INTO pg_ts_cfgmap (ts_name, tok_alias, dict_name)
	VALUES ('default_spanish', 'lword', '{es_ispell,en_stem}');

-- There are several other lexem types used that we do not need to specify as using the ISpell dictionary. We can simply insert values using the 'simple' stemming process dictionary.

INSERT INTO pg_ts_cfgmap
	VALUES ('default_spanish', 'url', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'host', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'sfloat', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'uri', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'int', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'float', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'email', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'word', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'hword', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'nlword', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'nlpart_hword', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'part_hword', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'nlhword', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'file', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'uint', '{simple}');
INSERT INTO pg_ts_cfgmap
        VALUES ('default_spanish', 'version', '{simple}');

END;
